#!/usr/bin/perl

use strict;
use DBI;
use Encode;
use Time::Local;

use GM;
use Drupal;

use constant DATA => '/data/www/coofercat/decaff/2004';

sub next_sequence
{
	my ($db,$name)=@_;

	my $sth=$db->prepare("select id from sequences where name='$name'");
	my $rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr";
	my @line = $sth->fetchrow_array;

	#print "Fetched $line[0] from $name sequence\n";
	my $id=$line[0] + 1;
	$sth=$db->prepare("replace into sequences values ('$name',$id)");

	$rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr";

	return $id;
}

sub run_sql
{
	my ($db,$sql)=@_;

	my $sth=$db->prepare($sql);
	my $rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr\n\nSQL was $sql";

	return $sth;
}

sub sqlify
{
	my ($sql)=@_;

	$sql=~s/\'/\\'/g;
	#$sql=~s/\!/\\!/g;

	$sql=encode('iso-8859-1',$sql);

	return $sql;
}

sub get_dir
{
        my ($dir)=@_;

        my @entries=();

        if(opendir(DIR,"$dir"))
        {
                @entries=readdir(DIR);
                close(DIR);
                @entries=grep(!/^\.+$/,@entries);
        }

        return (@entries);
}

sub read_file
{
        my ($filename)=@_;

        if(open(FILE,"< $filename"))
        {
                # File is open...
                my $contents="";

                my $keep=$/;
                $/=undef;
                $contents=<FILE>;
                $/=$keep;

                close(FILE);
                return $contents;
        }
        return undef;
}



MAIN:
{

	my $drupal = DBI->connect('DBI:mysql:decaff','coofer','catsrock');
	unless($drupal)
	{
		DBI::errstr;
		exit 1;
	}

	
	my @files=&get_dir(DATA);
	@files=sort grep(/^0.*\.cgi$/,@files);

	shift(@files);

	#@files="00000025.cgi";

	my $file;
	foreach $file (@files)
	{
		my $nfile=$file;
		$nfile=~s/\.cgi$/.html/;
		next unless(-f DATA . "/$nfile");

		my $contents=&read_file(DATA . "/$file");
		$contents=decode('utf8',$contents);
		my @lines=split(/\n/,$contents);

		my (undef,$author,$title,undef,$month,$day,$year,$hour,$minute,$sec,$ampm,undef)=split(/\|/,$lines[0],12);

		$month--;
		$hour=$hour + 12 if($ampm eq 'PM');
		$hour='0' if($hour eq '24');

		my $utc=timegm($sec,$minute,$hour,$day,$month,$year);
		my $date=gmtime($utc);

		print "Title: $title Date: $date $utc\n";

		my $teaser=GM::parse_text($lines[2]);
		my $body=GM::parse_text($lines[2]) . "\n<--break-->\n" . GM::parse_text($lines[3]);

		#print "Body: $body\n";

		my $nid=&next_sequence($drupal,'node_nid');
                my $vid=&next_sequence($drupal,'node_revisions_vid');

		#print "GM File " . DATA . " $file is drupal node $nid\n";

		my $details=GM::check_text($teaser);
		$details=GM::check_text($body) if($details eq '');

		$title=&sqlify($title);
		$teaser=&sqlify($teaser);
		$body=&sqlify($body);

                my $sql="insert into node (nid,vid,type,title,uid,status,created,changed,comment,promote,moderate,sticky) values ($nid,$vid,'blog','$title',1,1,$utc,$utc,2,0,0,0)";

		#print "SQl is $sql\n";
                my $drupal_sth=&run_sql($drupal,$sql);

                $sql="insert into node_revisions (nid,vid,uid,title,body,teaser,log,timestamp,format) values ($nid,$vid,1,'$title','$body','$teaser','',$utc,1)";
                $drupal_sth=&run_sql($drupal,$sql);

                # Now categorise the insert - Category 2 == 2004

                $sql="insert into term_node (nid,tid) values ($nid,2)";
                $drupal_sth=&run_sql($drupal,$sql);



		# now do comments...
		my $threadid=1;
		my $i;

		for($i=4; $i<=$#lines; $i++)
		{
			#print "Line: $lines[$i]\n";
			my ($cauth,$cip,$cemail,$curl,$dunno,$cmonth,$cday,$cyear,$chour,$cminute,$csec,$campm,$comment)=split(/\|/,$lines[$i],13);
			$cmonth--;
			$chour=$chour + 12 if($campm eq 'PM');
			$chour='0' if($chour eq '24');
			#print "Converting $csec,$cminute,$chour,$cday,$cmonth,$cyear\n";
			my $cutc=timegm($csec,$cminute,$chour,$cday,$cmonth,$cyear);
			my $cdate=gmtime($cutc);
			$comment=GM::parse_text($comment);

			#print "Comment Date: $cdate $cutc\n";
			#print "Comment: $comment\n";

			# Got a comment, handle it, and insert it...
                        my $cid=&next_sequence($drupal,'comments_cid');

                        my $uid=0;
                        $uid=1 if($cauth=~/coofer/i);

			my $thread=sprintf('%2d/',$threadid);
                        $thread=~s/\s/0/g;
			$threadid++;

			$comment=&sqlify($comment);
			$curl=&sqlify($curl);
			$cemail=&sqlify($cemail);
			$cauth=&sqlify($cauth);
			

			$sql="insert into comments (cid,pid,nid,uid,subject,comment,hostname,timestamp,score,status,format,thread,users,name,mail,homepage) values($cid,0,$nid,$uid,'$title','$comment','$cip',$cutc,0,0,1,'$thread','a:1:{i:0;i:0;}','$cauth','$cemail','$curl')";

                        #print "Comment SQL: $sql\n";

                        &run_sql($drupal,$sql);

                        Drupal::update_comment_stats($drupal,$nid);

		}

		print " ReWriteRule     \\/2004\\/$nfile\t\t\t/node/$nid [R,L]";
		if($details ne '')
		{
			print "\t$details\n";
		}
		else
		{
			print "\n";
		}

	}
}
