#!/usr/bin/perl

use strict;
use DBI;
use Encode;

use Tiki;
use Drupal;

sub next_sequence
{
	my ($db,$name)=@_;

	my $sth=$db->prepare("select id from sequences where name='$name'");
	my $rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr";
	my @line = $sth->fetchrow_array;

	#print "Fetched $line[0] from $name sequence\n";
	my $id=$line[0] + 1;
	$sth=$db->prepare("replace into sequences values ('$name',$id)");

	$rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr";

	return $id;
}

sub run_sql
{
	my ($db,$sql)=@_;

	my $sth=$db->prepare($sql);
	my $rc=$sth->execute
		or die "Can't execute statement: $DBI::errstr";

	return $sth;
}

sub sqlify
{
	my ($sql)=@_;

	$sql=~s/\'/\\'/g;
	$sql=~s/\!/\\!/g;

	$sql=encode('iso-8859-1',$sql);

	return $sql;
}

MAIN:
{

	my $tiki = DBI->connect('DBI:mysql:coofercat','coofer','catsrock');

	unless($tiki)
	{
		DBI::errstr;
		exit 1;
	}

	my $drupal = DBI->connect('DBI:mysql:decaff','coofer','catsrock');
	unless($drupal)
	{
		DBI::errstr;
		exit 1;
	}

	#my $tiki_sth = $tiki->prepare("select * from tiki_blog_posts where blogid=3 and postid=185");
	my $tiki_sth = $tiki->prepare("select * from tiki_blog_posts where blogid=3");

	my $rc = $tiki_sth->execute
	      or die "Can't execute statement: $DBI::errstr";

	print "Query will return $tiki_sth->{NUM_OF_FIELDS} fields.\n\n";
	  print "Field names: @{ $tiki_sth->{NAME} }\n";


	my @line;
	while (@line = $tiki_sth->fetchrow_array)
	{
	      #print "Line: @line\n";

		my $nid=&next_sequence($drupal,'node_nid');
		my $vid=&next_sequence($drupal,'node_revisions_vid');

		print "*** Handling Tiki Post $line[0] which is Drupal node $nid\n";

		# First, get the HMTL from Tiki for the blog post. This saves having to Wiki
		# parse the page and convert to HTML...
		my $data=Tiki::fetch_page($line[0]);
		if(!defined($data))
		{
			print "Didn't get data via Tiki for post $line[0] - using database data instead\n";
			$data=decode('utf8',$line[2]);
		}
		$data=Tiki::interpret_page($data);

		$line[8]=decode('utf8',$line[8]);
		$line[8]=&sqlify($line[8]);

		my $sql="insert into node (nid,vid,type,title,uid,status,created,changed,comment,promote,moderate,sticky) values ($nid,$vid,'blog','$line[8]',1,1,$line[4],$line[4],2,0,0,0)";
		my $drupal_sth=&run_sql($drupal,$sql);

		my ($teaser,$body)=Tiki::body_teaser($data);

		$teaser=sqlify($teaser);
		$body=sqlify($body);


		$sql="insert into node_revisions (nid,vid,uid,title,body,teaser,log,timestamp,format) values ($nid,$vid,1,'$line[8]','$body','$teaser','',$line[4],1)";
		$drupal_sth=&run_sql($drupal,$sql);

		# Now categorise the insert - Category 3 == 2005

		$sql="insert into term_node (nid,tid) values ($nid,3)";
		$drupal_sth=&run_sql($drupal,$sql);

		# Now do comments...
		$sql="select * from tiki_comments where objecttype='post' and object=$line[0] order by threadid";
		my $comments=&run_sql($tiki,$sql);
		my @comment;
		my $threadid=1;
		while (@comment = $comments->fetchrow_array)
		{
			# Got a comment, handle it, and insert it...
			my $cid=&next_sequence($drupal,'comment_cid');

			my $uid=0;
			$uid=1 if($comment[4] eq 'coofercat');

			my $thread=sprintf('%2d/',$threadid);
			$thread=~s/\s/0/g;

			my $url='';
			$url='http://www.coofercat.com/' if($uid==1);

			my $comment=sqlify(Tiki::parse_comment(decode('utf8',$comment[12])));

			my $mangle;
			foreach $mangle (11,14,4)
			{
				$comment[$mangle]=sqlify(decode('utf8',$comment[$mangle]));
			}

			$sql="insert into comments (cid,pid,nid,uid,subject,comment,hostname,timestamp,score,status,format,thread,users,name,mail,homepage) values($cid,0,$nid,$uid,'$comment[11]','$comment','$comment[14]',$comment[5],0,0,1,'$thread','a:1:{i:0;i:0;}','$comment[4]','','$url')";

			#print "Comment SQL: $sql\n";

			&run_sql($drupal,$sql);

			Drupal::update_comment_stats($drupal,$nid);
			
		}

		print "*** Done\n\n";
	}

	# check for problems which may have terminated the fetch early
	  die $tiki_sth->errstr if $tiki_sth->err;

	  $tiki->disconnect;
}
