package Tiki;

use constant TEASER_LENGTH => 0;

# Package to handle TikiWiki-isms in stuff from the database

use LWP;
use LWP::UserAgent;
use HTTP::Request;
use Encode;

sub body_teaser
{
	my ($data)=@_;

	my $body=$data;
	$body=~s/\.\.\.break\.\.\.//g;
	$body=~s/\.\.\.page\.\.\.//g;

	my $teaser=$body;
	if(TEASER_LENGTH > 0)
	{
		# Get the teaser, if there is one...
		$teaser=$data;
		my ($one,$two)=split(/\.\.\.break\.\.\./,$teaser,2);
		$teaser=$one;
		unless((defined($two)))
		{
			print "Using gnarly teaser split\n";
			$teaser=substr($teaser,0,TEASER_LENGTH);
			# Clean up...
			$teaser=~s/\s[^\s]*$//;
			$teaser=~s/\n[^\n]*$//;
			$teaser=$teaser . '...';
		}
		else
		{
			print "Teaser split on break\n";
		}
	}

	return ($teaser,$body);
}

sub fetch_page
{
	my ($postid)=@_;

	my $ua=LWP::UserAgent->new();

	my $request = new HTTP::Request( "GET", "http://www.coofercat.com/tiki/blog.php?postId=$postid" );

	 my $response=$ua->request($request);

	if($response->code() != 200)
	{
		print "Failed to fetch post id $postid: " . $response->code . "\n";
		return undef;
	}

	return decode('utf8',$response->content);
}

sub interpret_page
{
	my ($data)=@_;

	$data=~s/<br \/>/\n/g;

	$data=~s/<a([^>]*)class=\"([^\"]*)\"([^>]*)>/<a$1$3>/g;

	$data=~s/<(\/)?i>/<$1cite>/g;
	$data=~s/<(\/)?b>/<$1strong>/g;

	if($data=~/<img\s+/)
	{
		print "Post include an inline image that needs manual attention\n";
	}

	return $data;
}

sub link_handler
{
	my ($link)=@_;

	#print "Link handler called with link: $link\n";

	# Skip it if double bracketed (ie. [[some stuff] )
	return $link if($link=~/^\[\[/);

	# Remove square brackets...
	$link=~s/(\[|\])//g;

	my ($left,$right)=split(/\|/,$link,2);
	my $title;

	if((!defined($right)) || ($right eq ''))
	{
		$right=$left;
		$title=$left;
		# Remove any http:// from the URL
		$title=~s/^[^\/]*\/\///;
		# Now remove any path from the URL too
		$title=~s/\/.*$//;
	}
	else
	{
		$title=$right;
	}
	
	return "<a rel=\"nofollow\" href=\"$left\" title=\"$title\">$right</a>";

}

sub parse_comment
{
	my ($data)=@_;

	$data=~s/(\[[^\]]*\])/link_handler($1)/ge;

	return $data;
}

1;
